@@ -38,13 +38,6 @@ global_cli_context = {}
     show_default=True,
     help="Log level used for the analysis.",
 )
-@click.option(
-    "--show-twined-logs",
-    is_flag=True,
-    default=False,
-    show_default=True,
-    help="Show logs from the whole package in addition to logs just from your app.",
-)
 @click.option(
     "--force-reset/--no-force-reset",
     default=True,
@@ -53,7 +46,7 @@ global_cli_context = {}
     help="Forces a reset of analysis cache and outputs [For future use, currently not implemented]",
 )
 @click.version_option(version=pkg_resources.get_distribution("octue").version)
-def octue_cli(id, skip_checks, logger_uri, log_level, show_twined_logs, force_reset):
+def octue_cli(id, skip_checks, logger_uri, log_level, force_reset):
     """Octue CLI, enabling a data service / digital twin to be run like a command line application.
 
     When acting in CLI mode, results are read from and written to disk (see
@@ -65,13 +58,10 @@ def octue_cli(id, skip_checks, logger_uri, log_level, show_twined_logs, force_re
     global_cli_context["logger_uri"] = logger_uri
     global_cli_context["log_handler"] = None
     global_cli_context["log_level"] = log_level.upper()
-    global_cli_context["show_twined_logs"] = show_twined_logs
     global_cli_context["force_reset"] = force_reset
 
     if global_cli_context["logger_uri"]:
-        global_cli_context["log_handler"] = get_remote_handler(
-            logger_uri=global_cli_context["logger_uri"], log_level=global_cli_context["log_level"]
-        )
+        global_cli_context["log_handler"] = get_remote_handler(logger_uri=global_cli_context["logger_uri"])
 
 
 @octue_cli.command()
@@ -146,7 +136,6 @@ def run(app_dir, data_dir, config_dir, input_dir, output_dir, twine):
         skip_checks=global_cli_context["skip_checks"],
         log_level=global_cli_context["log_level"],
         handler=global_cli_context["log_handler"],
-        show_twined_logs=global_cli_context["show_twined_logs"],
     )
 
     analysis = runner.run(
@@ -218,7 +207,6 @@ def start(app_dir, data_dir, config_dir, service_id, twine, timeout, delete_topi
         skip_checks=global_cli_context["skip_checks"],
         log_level=global_cli_context["log_level"],
         handler=global_cli_context["log_handler"],
-        show_twined_logs=global_cli_context["show_twined_logs"],
     )
 
     backend_configuration_values = runner.configuration["configuration_values"]["backend"]
