@@ -130,7 +130,7 @@ class Service(CoolNameable):
         in the format specified in the Service's Twine file.
 
         :param dict data:
-        :param int question_uuid:
+        :param str question_uuid:
         :param float timeout:
         :raise Exception: if any exception arises during running analysis and sending its results
         :return None:
@@ -140,7 +140,9 @@ class Service(CoolNameable):
         )
 
         try:
-            analysis = self.run_function(input_values=data["input_values"], input_manifest=data["input_manifest"])
+            analysis = self.run_function(
+                input_values=data["input_values"], input_manifest=data["input_manifest"], analysis_id=question_uuid
+            )
 
             if analysis.output_manifest is None:
                 serialised_output_manifest = None
@@ -155,7 +157,7 @@ class Service(CoolNameable):
                 ).encode(),
                 retry=create_custom_retry(timeout),
             )
-            logger.info("%r responded on topic %r.", self, topic.path)
+            logger.info("%r responded to question %r.", self, question_uuid)
 
         except BaseException as error:  # noqa
             self._send_exception_to_asker(topic, timeout)
@@ -178,7 +180,7 @@ class Service(CoolNameable):
         if not question_topic.exists():
             raise octue.exceptions.ServiceNotFound(f"Service with ID {service_id!r} cannot be found.")
 
-        question_uuid = str(int(uuid.uuid4()))
+        question_uuid = str(uuid.uuid4())
 
         response_topic_and_subscription_name = ".".join((service_id, ANSWERS_NAMESPACE, question_uuid))
         response_topic = Topic(name=response_topic_and_subscription_name, namespace=OCTUE_NAMESPACE, service=self)
@@ -202,7 +204,7 @@ class Service(CoolNameable):
         )
         future.result()
 
-        logger.debug("%r asked question to %r service. Question UUID is %r.", self, service_id, question_uuid)
+        logger.info("%r asked a question %r to service %r.", self, question_uuid, service_id)
         return response_subscription, question_uuid
 
     def wait_for_answer(self, subscription, timeout=30):
@@ -245,7 +247,7 @@ class Service(CoolNameable):
             finally:
                 try:
                     self.subscriber.acknowledge(request={"subscription": subscription.path, "ack_ids": [answer.ack_id]})
-                    logger.debug("%r received a response to question on topic %r.", self, subscription.topic.path)
+                    logger.info("%r received a response to question %r.", self, subscription.topic.path.split(".")[-1])
                 except UnboundLocalError:
                     pass
 
@@ -308,4 +310,4 @@ class Service(CoolNameable):
 
         # Allow unknown exception types to still be raised.
         except KeyError:
-            raise Exception(f"{data['exception_type']}: {message}")
+            raise type(data["exception_type"], (Exception,), {})(message)
